##  Standard User Roles
The following table lists standard user roles available in SAP LeanIX.
User Role | Default Fact Sheet Permissions
---|---
Viewer | Can view, subscribe to, and comment on all fact sheets.
Member | Can view, create, and modify all fact sheets.
Admin | Has all permissions of a member user as well as administrator permissions for a workspace.


As an admin, you can adjust permissions for non-admin roles. For more information, see [Role-Based Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD#loio275def827a4410149362f3672c614956__role-based_permissions).
